@@ -218,9 +218,6 @@ async def create_task(request: ImageRequest, token: Optional[str] = None):  # to
 
     headers = get_headers(url, token)
 
-    if "http" in request.prompt:  # 图生
-        request.model = "high_aes_general_v20_L:general_v2.0_L"
-
     draft_content = await create_draft_content(request, token)
 
     logger.debug(json.dumps(draft_content))
@@ -663,7 +660,7 @@ if __name__ == '__main__':
     # arun(generate(ImageRequest(prompt="fuck you")))
     prompt = "A plump Chinese beauty wearing a wedding  dress revealing her skirt and underwear is swinging on the swing,Happy smile,cleavage,Exposed thighs,Spread your legs open,Extend your leg,panties,upskirt,Barefoot,sole"
     # prompt = "a dog cat in the same room"
-    prompt = "https://oss.ffire.cc/files/kling_watermark.png 让这个女人带上墨镜，衣服换个颜色... ! "
+    prompt = "https://oss.ffire.cc/files/kling_watermark.png 让这个女人带上墨镜，衣服换个颜色..  . ! "
     request = ImageRequest(prompt=prompt, size="1328x1328")
     # request = ImageRequest(prompt=prompt, size="1024x1024")
 
