@@ -14,6 +14,7 @@ from meutils.apis.utils import make_request_httpx
 from meutils.apis.oneapi.log import get_logs
 from meutils.apis.oneapi.user import update_user_for_refund, get_user
 
+
 # headers
 ACTIONS = {
     # 按量计费的异步任务
@@ -36,7 +37,7 @@ ACTIONS = {
 }
 
 
-async def get_tasks(platform: str = "flux", action: str = "", status: str = "NOT_START"):
+async def get_tasks(platform: str = "flux", action: str = "", status: str = "NOT_START", return_ids: bool = False):
     base_url = "https://api.chatfire.cn"
     path = "/api/task/"
     headers = {
@@ -66,6 +67,11 @@ async def get_tasks(platform: str = "flux", action: str = "", status: str = "NOT
         params=params,
         headers=headers
     )
+    if return_ids:
+        # from meutils.str_utils.json_utils import json_path
+
+        return [item['task_id'] for item in response['data']['items']] | xUnique
+
     return response
 
 
@@ -74,7 +80,7 @@ async def polling_tasks(platform: str = "flux", action: str = "", status: str =
     if items := response['data']['items']:
         tasks = []
         model = ''
-        for item in items[:8]:  # 批量更新
+        for item in items[:128]:  # 批量更新
             task_id = item['task_id']
             action = item['action'].split('-', maxsplit=1)[0]  # 模糊匹配
             if 'fal-' in item['action']:
@@ -139,7 +145,11 @@ async def refund_tasks(task_id: Optional[str] = None):  # 只补偿一次
 
 
 if __name__ == '__main__':
+
     pass
     arun(polling_tasks())
-    # arun(get_tasks(action="async-task", status="FAILURE"))
+    # arun(get_tasks(action="jimeng-video-3.0", status="FAILURE"))
+    # arun(get_tasks(action="jimeng-video-3.0", return_ids=True))
+
+
     # arun(refund_tasks())
