@@ -6,7 +6,7 @@
 # @Author       : betterme
 # @WeChat       : meutils
 # @Software     : PyCharm
-# @Description  :
+# @Description  : https://ppio.com/pricing
 
 from meutils.pipe import *
 from meutils.db.redis_db import redis_aclient
@@ -21,6 +21,7 @@ base_url = "https://api.ppinfra.com/v3"
 feishu_url = "https://xchatllm.feishu.cn/sheets/Z59Js10DbhT8wdt72LachSDlnlf?sheet=b0e241"
 
 
+
 async def get_valid_token(min_points=18000):
     _ = await get_next_token(feishu_url, check_token, min_points=min_points, ttl=600)
     logger.debug(_)
@@ -28,8 +29,13 @@ async def get_valid_token(min_points=18000):
 
 
 # minimax-hailuo-02-6s-768p minimax-hailuo-02-6s-768p minimax-hailuo-02-6s-1080p
+
 async def create_task(request: VideoRequest, api_key: Optional[str] = None):
-    api_key = api_key or await get_valid_token()  # 轮询
+    api_key = api_key or await get_valid_token()
+
+    api_key="sk_4Ja29OIUBVwKo5GWx-PRTsRcTyxxRjZDpYxSdPg75QU"
+
+    path = "/async/minimax-hailuo-02"
 
     payload = {
 
@@ -44,7 +50,7 @@ async def create_task(request: VideoRequest, api_key: Optional[str] = None):
         base_url=base_url,
         api_key=api_key,
 
-        path="/async/minimax-hailuo-02",
+        path=path,
         payload=payload,
     )
 
@@ -148,12 +154,27 @@ if __name__ == '__main__':
         resolution="768P",
     )
     api_key = None
-    # r = arun(create_task(request, api_key=api_key))
+    r = arun(create_task(request, api_key=api_key))
 
-    # arun(get_task("d8b048d0-5c54-42ef-a691-3feab31693fe"))
+    # arun(get_task("d425c44f-da09-4cff-a471-f78757786046"))
 
     # print(request.model_dump_json(exclude_none=True))
 
     # arun(get_task("959d759e-da77-42f9-95c5-c29cccc6a894"))
 
-    arun(get_valid_token())
+    # arun(get_valid_token())
+
+# "0c830895-1933-4c41-a0cb-37b7387b643a"
+"""
+curl \
+-X POST https://api.ppinfra.com/v3/async/minimax-hailuo-02 \
+-H "Authorization: Bearer sk_4Ja29OIUBVwKo5GWx-PRTsRcTyxxRjZDpYxSdPg75QU" \
+-H "Content-Type: application/json" \
+-d '{
+  "image_url": "https://static.ppinfra.com/docs/assets/minimax-hailuo-video-02-input-image.jpg",
+  "prompt": "戴着太阳镜的毛茸茸的熊猫在日出时的雪山顶上跳舞，左移运镜",
+  "duration": 6,
+  "resolution": "1080P",
+  "enable_prompt_expansion": true
+}'
+"""
\ No newline at end of file
