@@ -62,6 +62,6 @@ if __name__ == '__main__':
         loop.run_until_complete(asyncio.wait(tasks))
 
 
-    run()
+    # run()
 
-    # arun(get_one_proxy())
+    arun(get_one_proxy())
