@@ -195,6 +195,7 @@ async def check_token_for_sophnet(api_key, threshold: float = 1):
 
     try:
         client = AsyncOpenAI(base_url=os.getenv("SOPHNET_BASE_URL"), api_key=api_key)
+        print(await client.models.list())
         data = await client.chat.completions.create(
             model="DeepSeek-v3",
             messages=[{"role": "user", "content": "hi"}],
@@ -212,7 +213,7 @@ async def check_token_for_sophnet(api_key, threshold: float = 1):
 
 #
 @retrying()
-@rcache(ttl=3600, skip_cache_func=skip_cache_func)
+# @rcache(ttl=7 * 24 * 3600, skip_cache_func=skip_cache_func)
 async def check_token_for_volc(api_key, threshold: float = 1, purpose: Optional[str] = None):
     if not isinstance(api_key, str):
         return await check_tokens(api_key, check_token_for_volc)
@@ -225,8 +226,8 @@ async def check_token_for_volc(api_key, threshold: float = 1, purpose: Optional[
             url = "https://ark.cn-beijing.volces.com/api/v3/contents/generations/tasks"
 
             payload = {
-                "model": "doubao-seedance-1-0-pro-250528",
-                # "model":"doubao-seedance-1-0-lite-i2v-250428",
+                # "model": "doubao-seedance-1-0-pro-250528",
+                "model":"doubao-seedance-1-0-lite-i2v-250428",
                 "content": [
                     {
                         "type": "text",
@@ -266,6 +267,7 @@ async def check_token_for_volc(api_key, threshold: float = 1, purpose: Optional[
                 messages=[{"role": "user", "content": "hi"}],
                 max_tokens=1
             )
+            # logger.debug(response.json())
 
         return True
     except TimeoutException as e:
@@ -286,7 +288,7 @@ async def check_token_for_zhipu(api_key, threshold: float = 1, resource_package_
     try:
         client = AsyncOpenAI(base_url="https://bigmodel.cn/api/biz/tokenAccounts/list", api_key=api_key)
         data = await client.get("", cast_to=object)
-        logger.debug(bjson(data))
+        # logger.debug(bjson(data))
 
         if resource_package_name:
             # print(str(data))
@@ -298,8 +300,8 @@ async def check_token_for_zhipu(api_key, threshold: float = 1, resource_package_
             # "resourcePackageName": "【新用户专享】200万GLM-Z1-Air推理资源包",
             # "resourcePackageName": "【新用户专享】30次Vidu系列视频生成次包",
             for d in data["rows"]:
-                if resource_package_name.lower() in d["resourcePackageName"].lower():
-                    # logger.debug(bjson(d))
+                if resource_package_name.lower() in d["resourcePackageName"].lower() and d['status'] != "EXPIRED":
+                    logger.debug(bjson(d))
                     return d["tokenBalance"] >= threshold
         else:
             logger.debug(bjson(data))
@@ -398,12 +400,13 @@ if __name__ == '__main__':
 
     # arun(check_token_for_ppinfra("sk_F0kgPyCMTzmOH_-VCEJucOK8HIrbnLGYm_IWxBToHZQ"))
 
-    arun(check_token_for_volc("97237d3b-76b3-4a92-8150-5b64bba0b8b1"))
+    # arun(check_token_for_volc("c720b2fb-e2be-42a7-a9e5-0a42c29d5766"))
     # arun(check_token_for_volc("279749bd-ba5e-4962-9c65-eb6604b65594"))
+    arun(check_token_for_volc("8a5af7cb-42a3-4391-ac40-9d0f4502acde", purpose='seedance'))
 
     # arun(check_token_for_ppinfra("sk_mCb5sRGTi6GXkSRp5F679Rbs0V_Hfee3p85lccGXCOo"))
 
-    arun(check_token_for_zhipu(api_key="e130b903ab684d4fad0d35e411162e99.PqyXq4QBjfTdhyCh"))
+    # arun(check_token_for_zhipu(api_key="e130b903ab684d4fad0d35e411162e99.PqyXq4QBjfTdhyCh"))
 
     # arun(check_token_for_fal("56d8a95e-2fe6-44a6-8f7d-f7f9c83eec24:537f06b6044770071f5d86fc7fcd6d6f"))
 
