@@ -35,6 +35,14 @@ class Completions(object):
 
     async def create(self, request: CompletionRequest):
 
+        if request.model.startswith("doubao-seed"):  # todo: 1-5
+            choices = """
+            doubao-seed-1-6-250615
+            doubao-seed-1-6-thinking-250615
+            doubao-seed-1-6-thinking-250715
+            doubao-seed-1-6-vision-250815
+            """.split()
+            request.model = np.random.choice(choices)
         ###########################################################################
         # 开启视觉模型
         if not any(i in request.model.lower() for i in ["v-", "vl", 'vision', 'doubao-seed']) and (
