@@ -7,14 +7,16 @@
 # @WeChat       : meutils
 # @Software     : PyCharm
 # @Description  :
-import json
+from aiostream import stream
 
 from meutils.pipe import *
 from meutils.io.files_utils import to_url, to_url_fal
 from meutils.str_utils.json_utils import json_path
-from meutils.schemas.openai_types import CompletionRequest
+from meutils.llm.openai_utils import create_chat_completion
+from meutils.schemas.openai_types import CompletionRequest, ChatCompletion
 from meutils.schemas.image_types import ImageRequest
 from meutils.llm.openai_utils import chat_completion, chat_completion_chunk, create_chat_completion_chunk
+from meutils.str_utils import parse_url, parse_command_string
 
 
 async def stream_to_nostream(
@@ -24,11 +26,12 @@ async def stream_to_nostream(
 
 
 async def chat_for_image(
-        generate: Callable,
+        generate: Optional[Callable],
         request: CompletionRequest,
         api_key: Optional[str] = None,
+        base_url: Optional[str] = None,
 ):
-    generate = partial(generate, api_key=api_key)
+    generate = generate and partial(generate, api_key=api_key, base_url=base_url)
 
     if not request.stream or request.last_user_content.startswith(  # 跳过nextchat
             (
@@ -39,16 +42,46 @@ async def chat_for_image(
         chat_completion.choices[0].message.content = "请设置`stream=True`"
         return chat_completion
 
+        # request.stream = True  # 流转非流
+        # response = await chat_for_image(generate, request, api_key)
+        # chunks = await stream.list(response)
+        #
+        # logger.debug(chunks)
+        #
+        # if chunks and isinstance(chunks[0], ChatCompletion):
+        #     response = chunks[0]
+        # else:
+        #     response = create_chat_completion(chunks)
+        # return response
+    image = None
     prompt = request.last_user_content
-    if request.last_urls:  # image_url
-        urls = await to_url_fal(request.last_urls["image_url"], content_type="image/png")
-        prompt = "\n".join(urls + [prompt])
+    if image_urls := request.last_urls.get("image_url"):  # image_url
+        if request.model.startswith('fal'):
+            urls = await to_url_fal(image_urls, content_type="image/png")  # 国外友好
+            image = urls
+        else:
+            urls = await to_url(image_urls, content_type="image/png") # 数组
+            image = urls[-1]
 
     request = ImageRequest(
         model=request.model,
         prompt=prompt,
+        image=image
     )
+    if not request.image:
+        request.image, request.prompt = request.image_and_prompt
 
+    if '--' in request.prompt:
+        prompt_dict = parse_command_string(request.prompt)
+
+        data = {
+            **request.model_dump(exclude_none=True, exclude={"extra_fields", "aspect_ratio"}),
+            **prompt_dict
+        }
+        request = ImageRequest(**data)
+        logger.debug(request)
+
+    if not generate: return
     future_task = asyncio.create_task(generate(request))  # 异步执行
 
     async def gen():
@@ -65,7 +98,6 @@ async def chat_for_image(
     return chunks
 
 
-
 async def chat_for_video(
         get_task: Callable,  # response
         taskid: str,
@@ -100,7 +132,7 @@ async def chat_for_video(
             else:
                 yield "🚀"
 
-    chunks = create_chat_completion_chunk(gen())
+    chunks = create_chat_completion_chunk(gen(), chat_id=taskid)
     return chunks
 
 
@@ -108,8 +140,8 @@ if __name__ == '__main__':
     request = CompletionRequest(
         model="deepseek-r1-Distill-Qwen-1.5B",
         messages=[
-            {"role": "user", "content": "``hi"}
+            {"role": "user", "content": "``hi --a 1"}
         ],
-        stream=False,
+        stream=True,
     )
     arun(chat_for_image(None, request))
