@@ -35,7 +35,7 @@ async def billing_for_async_task(
         model: str = "async-task",
         task_id: str = "sync",
         n: float = 1,
-        api_key: Optional[str] = None
+        api_key: Optional[str] = None  ########## 注意
 ):
     model = model.lower().replace('/', '-')  # 统一小写 # wan-ai-wan2.1-t2v-14b
     if n := int(np.round(n)):
@@ -263,7 +263,10 @@ if __name__ == '__main__':
     model = "Wan-AI/Wan2.1-T2V-14B"
 
     # arun(billing_for_async_task(model, task_id=task_id, n=3))
-    arun(billing_for_async_task(task_id='fal-ai-sync'))
+    # arun(billing_for_async_task(task_id='fal-ai-sync'))
+    arun(billing_for_async_task())
+
+
 
     # data = {
     #     "model": "doubao-seedance-1-0-pro-250528",
