@@ -9,7 +9,7 @@
 # @Description  : todo: 通用比例适配
 
 from meutils.pipe import *
-from meutils.str_utils import parse_url
+from meutils.str_utils import parse_url, parse_command_string
 from meutils.math_utils import size2aspect_ratio
 
 from pydantic import constr
@@ -108,7 +108,7 @@ class ImageRequest(BaseModel):  # openai
     guidance: Optional[float] = None
     steps: Optional[int] = None
 
-    controls: Optional[dict] = None # 额外参数
+    controls: Optional[dict] = None  # 额外参数
 
     safety_tolerance: Optional[int] = None
 
@@ -116,10 +116,13 @@ class ImageRequest(BaseModel):  # openai
 
     user: Optional[str] = None  # to_url_fal
 
+    image: Optional[Union[str, List[str]]] = None  # url b64
+    watermark: Optional[bool] = None
+
     def __init__(self, /, **data: Any):
         super().__init__(**data)
 
-        if self.aspect_ratio and self.size is None:  # 适配比例
+        if self.aspect_ratio:  # 适配比例
             self.size = ASPECT_RATIOS.get(self.aspect_ratio, '1024x1024')
 
         elif self.size == 'auto':
@@ -130,6 +133,15 @@ class ImageRequest(BaseModel):  # openai
 
             self.size = self.size if 'x' in self.size else '512x512'
 
+    @cached_property
+    def image_urls(self):
+        if self.image:
+            if isinstance(self.image, str):
+                return [self.image]
+            else:
+                return self.image
+        return []
+
     @cached_property
     def image_and_prompt(self):  # image prompt 目前是单图
         if self.prompt.startswith('http') and (prompts := self.prompt.split(maxsplit=1)):
@@ -618,4 +630,4 @@ if __name__ == '__main__':
 
     r = ImageRequest(**data)
 
-    print(ImagesResponse())
+    # print(ImagesResponse())
