@@ -25,6 +25,9 @@ MINIMAX_VIDEO = 2 * 0.6
 FAL = 3
 FAL_ = 5
 FAL_MODELS = {
+    #
+    "fal-ai/clarity-upscaler": 1,  # Your request will cost $0.03 per upscaled megapixel.
+
     'fal-kling-video-lipsync-audio-to-video': 0.5,
 
     'fal-pixverse-v4.5-effects': 1,
@@ -107,7 +110,8 @@ FAL_MODELS = {
 MODEL_PRICE = {
     **FAL_MODELS,
 
-    "qwen-image": 0.1,
+    "qwen-image": 0.05,
+    "qwen-image-edit": 0.05,
 
     "wan-ai-wan2.1-t2v-14b": 1,
     "wan-ai-wan2.1-t2v-14b-turbo": 1,
@@ -198,6 +202,7 @@ MODEL_PRICE = {
     "minimax-i2v-01_6s_720p": 1 * MINIMAX_VIDEO,
     "minimax-i2v-01-director_6s_720p": 1 * MINIMAX_VIDEO,
     "minimax-i2v-01-live_6s_720p": 1 * MINIMAX_VIDEO,
+
     "minimax-s2v-01_6s_720p": 1.5 * MINIMAX_VIDEO,
     "minimax-hailuo-02_6s_512p": 0.3 * MINIMAX_VIDEO,
     "minimax-hailuo-02_10s_512p": 0.5 * MINIMAX_VIDEO,
@@ -221,10 +226,6 @@ MODEL_PRICE = {
     "qwen3-reranker-4b": 0.0011,
     "qwen3-reranker-8b": 0.0011,
 
-    "qwen3-embedding-0.6b": 0.0011,
-    "qwen3-embedding-4b": 0.0011,
-    "qwen3-embedding-8b": 0.0011,
-
     # 视频
     "api-videos-3d": 0.01,
     "api-videos-3d-1.5": 0.01,
@@ -248,13 +249,7 @@ MODEL_PRICE = {
 
     # 官方apit todo 免费模型
     "cogvideox-flash": 0.05,
-    "cogvideox": 0.1,
-    "cogvideox-2": 0.2,
     "cogvideox-3": 0.3,
-    "cogvideox-3-flash": 0.1,
-
-    "official-api-cogvideox": 0.1,
-    "official-api-kling-video": 0.5,
 
     "api-videos-seedream-3.0": 0.5,
 
@@ -484,9 +479,11 @@ MODEL_PRICE = {
 
     "deepseek-search": 0.01,
     'deepseek-r1-search': 0.01,
-    "deepseek-r1-search-pro": 0.02,
-    "deepseek-r1-search-pro-thinking": 0.02,
+    "deepseek-r1-search-pro": 0.01,
+    "deepseek-r1-search-pro-thinking": 0.01,
     'deepseek-reasoner-search': 0.01,
+    "doubao-1.5-search": 0.01,
+    "deepseek-v3.1-search": 0.01,
 
     # MJ
     "mj-chat": 0.3,
@@ -543,8 +540,18 @@ MODEL_RATIO = {
     "elevenlabs/scribe_v1": 3 * 0.03 * 1000 / 60 / 2,  # Your request will cost $0.03 per minute of audio transcribed
     "elevenlabs/eleven_multilingual_v2": 3 * 0.1 * 1000 / 2,
     "elevenlabs/eleven_turbo_v2_5": 3 * 0.05 * 1000 / 2,  # Your request will cost $0.05 per thousand characters.
+    "elevenlabs/eleven_v3": 3 * 0.05 * 1000 / 2,  # Your request will cost $0.05 per thousand characters.
+
+    'elevenlabs/eleven_flash_v2_5': 3 * 0.05 * 1000 / 2,
+    'elevenlabs/eleven_turbo_v2': 3 * 0.05 * 1000 / 2,
+    'elevenlabs/eleven_flash_v2': 3 * 0.05 * 1000 / 2,
+    'elevenlabs/eleven_monolingual_v1': 3 * 0.05 * 1000 / 2,
+    'elevenlabs/eleven_english_sts_v2': 3 * 0.05 * 1000 / 2,
+    'elevenlabs/eleven_multilingual_sts_v2': 3 * 0.05 * 1000 / 2,
+    'elevenlabs/eleven_multilingual_v1': 3 * 0.05 * 1000 / 2,
 
     "fal-elevenlabs-speech-to-text": 3 * 0.03 * 1000 / 60 / 2,
+    "fal-elevenlabs-tts-eleven-v3": 3 * 0.03 * 1000 / 60 / 2,
     'fal-elevenlabs-tts-turbo-v2.5': 3 * 0.05 * 1000 / 2,
     'fal-elevenlabs-tts-multilingual-v2': 3 * 0.1 * 1000 / 2,
 
@@ -592,6 +599,14 @@ MODEL_RATIO = {
     "jina-embeddings-v4": 0.1,
     "jina-reranker-m0": 0.1,
 
+    "qwen3-embedding-0.6b": 0.1,
+    "qwen3-embedding-4b": 0.1,
+    "qwen3-embedding-8b": 0.1,
+
+    "doubao-embedding-vision-250615": 0.9,
+    "doubao-embedding-large-text-250515": 0.25,
+    "doubao-embedding-text-240715": 0.35,
+
     # 百川
     'baichuan4-turbo': 7.5,
     'baichuan4-air': 0.49,
@@ -667,10 +682,10 @@ MODEL_RATIO = {
     "glm-4.1v-thinking-flashx": 1,
 
     "glm-4.5-flash": 0.1,
-    "glm-4.5-air": 0.2,
+    "glm-4.5-air": 0.4,
     "glm-4.5-airx": 1,
-    "glm-4.5": 1,
-    "glm-4.5-x": 2,
+    "glm-4.5": 2,
+    "glm-4.5-x": 6,
     "glm-4.5v": 1,
 
     # 阿里千问 https://dashscope.console.aliyun.com/billing
@@ -711,8 +726,8 @@ MODEL_RATIO = {
     "qwen3-235b-a22b": 1,
     "qwen-math-plus": 2,
     "qwen3-coder-480b-a35b-instruct": 3,
-    "qwen3-235b-a22b-instruct-2507": 1,
-    "qwen3-235b-a22b-thinking-2507": 3,
+    "qwen3-235b-a22b-instruct-2507": 2,
+    "qwen3-235b-a22b-thinking-2507": 2,
 
     "qwen3-coder-plus": 2,
     "qwen3-coder-plus-2025-07-22": 2,
@@ -801,6 +816,9 @@ MODEL_RATIO = {
     "deepseek-v3-8k": 0.5,
     "deepseek-v3-128k": 5,
     "deepseek-chat": 1,
+    "deepseek-v3.1": 2,
+    "deepseek-v3-1-250821": 2,
+    "deepseek-v3-1-think": 2,
 
     "deepseek-chat-8k": 0.5,
     "deepseek-chat-64k": 5,
@@ -857,6 +875,7 @@ MODEL_RATIO = {
     "doubao-seed-1-6-250615": 0.4,
     "doubao-seed-1-6-thinking-250615": 0.4,
     "doubao-seed-1-6-thinking-250715": 0.4,
+    "doubao-seed-1-6-vision-250815": 0.6,
 
     "doubao-1-5-ui-tars-250428": 1.75,
     "ui-tars-72b": 1.75,
@@ -877,6 +896,8 @@ MODEL_RATIO = {
     "doubao-pro-4k": 0.4,
     "doubao-pro-32k": 0.4,
     "doubao-pro-32k-character": 0.4,
+    "doubao-pro-32k-character-241215": 0.4,
+
     "doubao-pro-128k": 2.5,
     "doubao-pro-256k": 2.5,
     "doubao-1.5-pro-32k": 0.4,
@@ -1461,7 +1482,7 @@ COMPLETION_RATIO = {
     "qwen3-235b-a22b": 4,
     "qwenlong-l1-32b": 4,
     "qwen3-235b-a22b-instruct-2507": 4,
-    "qwen3-235b-a22b-thinking-2507": 4,
+    "qwen3-235b-a22b-thinking-2507": 10,
     "qwen3-coder-480b-a35b-instruct": 4,
 
     "qwen3-coder-plus": 4,
@@ -1476,6 +1497,7 @@ COMPLETION_RATIO = {
     "doubao-seed-1-6-250615": 10,
     "doubao-seed-1-6-thinking-250615": 10,
     "doubao-seed-1-6-thinking-250715": 10,
+    "doubao-seed-1-6-vision-250815": 13.33,
 
     "doubao-1-5-ui-tars-250428": 3.43,
     "ui-tars-72b": 4,
@@ -1490,6 +1512,7 @@ COMPLETION_RATIO = {
     "doubao-pro-4k": 3,
     "doubao-pro-32k": 2.5,
     "doubao-pro-32k-character": 3,
+    "doubao-pro-32k-character-241215": 3,
     "doubao-pro-128k": 3,
     "doubao-pro-256k": 1.8,
     "doubao-1.5-pro-32k": 2.5,
@@ -1547,6 +1570,9 @@ COMPLETION_RATIO = {
     "deepseek-v3-250324": 4,
     "deepseek-chat": 4,
     "deepseek-v3-fast": 4,
+    "deepseek-v3.1": 3,
+    "deepseek-v3-1-250821": 3,
+    "deepseek-v3-1-think": 3,
 
     'deepseek-r1': 4,
     "deepseek-r1-160k": 5,
@@ -1587,8 +1613,8 @@ COMPLETION_RATIO = {
     "glm-4.1v-thinking-flashx": 4,
 
     "glm-4.5-flash": 3,
-    "glm-4.5-air": 3,
-    "glm-4.5-airx": 3,
+    "glm-4.5-air": 7.5,
+    "glm-4.5-airx": 4,
     "glm-4.5": 4,
     "glm-4.5-x": 4,
     "glm-4.5v": 3,
